@@ -11,7 +11,7 @@ from mldock.config.config_manager import \
         HyperparameterConfigManager, InputDataConfigManager
 from mldock.api.local import \
     run_predict, _copy_boilerplate_to_dst, docker_build, \
-        local_train, local_deploy_detached, _rename_file
+        local_train, local_deploy, _rename_file
 
 from mldock.api.local import \
     train_model, deploy_model
@@ -194,7 +194,7 @@ def deploy(obj, dir, tag, host):
         logger.info("Started local deployment at {}...\n".format(host))
         if platform == "sagemaker":
         
-            local_deploy_detached(
+            local_deploy(
                 dir=module_path,
                 docker_tag=tag,
                 image_name=image_name
